# Changelog

## [Unreleased][]

[Unreleased]: https://github.com/chaostoolkit/chaosplatform-scheduling/compare/0.1.0...HEAD

## [0.1.0][] - 2018-11-01

[0.1.0]: https://github.com/chaostoolkit/chaosplatform-scheduling/tree/0.1.0

### Added

-   Initial release